# [版本更新](https://github.com/pydtools/drfcommon/blob/main/CHANGELOG.md)
drfcommon

[0.1.6] list data add items 
[0.1.8] data format
[0.1.8.2] viewset 定制异常处理
[0.1.8.3] is_deleted
[0.1.8.6] describe -> message
[0.1.8.6.9] update 保持一致
[0.1.8.7] 异常加入 405
[0.1.9] 异常msg返回str
[0.1.9.1] 日志级别修正
[0.1.9.2] 日志级别修正v2
[0.1.9.3] 日志级别修正v3
[0.1.9.4] 加入异常空页面
